@@ -34,7 +34,7 @@ def findChanges(old_state,new_state):
                     if datetime.datetime.strptime(old_state["value"],"%Y-%m-%d").strftime("%Y-%m-%d") != new_state:
                         res += "<li> %s ----> %s</li>" % (old_state.get("value"), new_state)
                 break
-            elif old_state[key]!=new_state.get(key,None):
+            elif new_state is not None and old_state[key]!=new_state.get(key,None):
                 if type(old_state[key]) in [type({}),type([])]:
                     try:
                         c = findChanges(old_state.get(key, {}), new_state.get(key, {}))
